@@ -14,7 +14,7 @@
 
 # taken from the instructions above
 TIMESTAMP="2010-03-06 19:17:21"
-CERTGUID="8be4df61-93ca-11d2-aa0d-00e098032b8c"
+CERTGUID="77fa9abd-0359-4d32-bd60-28f4e78f784b"
 
 # the 2023 microsoft kek certificate
 CERTFILE="/usr/share/virt-sb-certs/microsoft.com/ms-kek-2023.pem"
